Learn R Programming

estimateW (version 0.1.0)

beta_priors: Set prior specifications for the slope parameters

Description

This function allows the user to specify custom values for Gaussian priors on the slope parameters.

Usage

beta_priors(
  k,
  beta_mean_prior = matrix(0, k, 1),
  beta_var_prior = diag(k) * 100
)

Value

A list with the prior mean vector (beta_mean_prior), the prior variance matrix (beta_var_prior) and the inverse of the prior variance matrix (beta_var_prior_inv).

Arguments

k

The total number of slope parameters in the model.

beta_mean_prior

numeric \(k\) by \(1\) matrix of prior means \(\underline{\mu}_\beta\).

beta_var_prior

A \(k\) by \(k\) matrix of prior variances \(\underline{V}_\beta\). Defaults to a diagonal matrix with 100 on the main diagonal.

Details

For the slope parameters \(\beta\) the package uses common Normal prior specifications. Specifically, \(p(\beta)\sim\mathcal{N}(\underline{\mu}_\beta,\underline{V}_\beta)\).

This function allows the user to specify custom values for the prior hyperparameters \(\underline{\mu}_\beta\) and \(\underline{V}_\beta\). The default values correspond to weakly informative Gaussian priors with mean zero and a diagonal prior variance-covariance matrix with \(100\) on the main diagonal.