Learn R Programming

estimateW (version 0.1.0)

rho_priors: Specify prior for the spatial autoregressive parameter and sampling settings

Description

Specify prior for the spatial autoregressive parameter and sampling settings

Usage

rho_priors(
  rho_a_prior = 1,
  rho_b_prior = 1,
  rho_min = 0,
  rho_max = 1,
  init_rho_scale = 1,
  griddy_n = 60,
  use_griddy_gibbs = TRUE,
  mh_tune_low = 0.4,
  mh_tune_high = 0.6,
  mh_tune_scale = 0.1
)

Arguments

rho_a_prior

Single number. Prior hyperparameter for the four-parameter beta distribution betapdf. Defaults to 1.

rho_b_prior

Single number. Prior hyperparameter for the four-parameter beta distribution betapdf. Defaults to 1.

rho_min

Minimum value for \(\rho\) (default: 0)

rho_max

Maximum value for \(\rho\) (default: 1)

init_rho_scale

For Metropolis-Hastings step the initial candidate variance (default: 1)

griddy_n

single integer number. Sets how fine the grid approximation is. Default value is 60.

use_griddy_gibbs

Binary value. Should griddy-Gibbs be used for \(\rho\) estimation? use_griddy_gibbs=TRUE does not work if row_standardized_prior = FALSE is specified in the \(W\) prior specification. if TRUE: griddy-Gibbs step for sampling \(\rho\); if FALSE: tuned random-walk Metropolis-Hastings step

mh_tune_low

Lower bound of acceptance rate for Metropolis-Hastings tuning (used if use_griddy_gibbs==FALSE)

mh_tune_high

Upper bound of acceptance rate for Metropolis-Hastings tuning (used if use_griddy_gibbs==FALSE)

mh_tune_scale

Scaling factor for Metropolis-Hastings tuning (used if use_griddy_gibbs==FALSE)