This function allows the user to specify custom values for Gaussian priors on the slope parameters.
beta_priors(
k,
beta_mean_prior = matrix(0, k, 1),
beta_var_prior = diag(k) * 100
)A list with the prior mean vector (beta_mean_prior), the prior variance matrix
(beta_var_prior) and the inverse of the prior variance matrix (beta_var_prior_inv).
The total number of slope parameters in the model.
numeric \(k\) by \(1\) matrix of prior means \(\underline{\mu}_\beta\).
A \(k\) by \(k\) matrix of prior variances \(\underline{V}_\beta\). Defaults to a
diagonal matrix with 100 on the main diagonal.
For the slope parameters \(\beta\) the package uses common Normal prior specifications. Specifically, \(p(\beta)\sim\mathcal{N}(\underline{\mu}_\beta,\underline{V}_\beta)\).
This function allows the user to specify custom values for the prior hyperparameters \(\underline{\mu}_\beta\) and \(\underline{V}_\beta\). The default values correspond to weakly informative Gaussian priors with mean zero and a diagonal prior variance-covariance matrix with \(100\) on the main diagonal.